# Samsung AI Challenge solution

본 repository를 통해 2021년 DACON을 통해 개최된 [Samsung AI Challenge for Scientific Discovery](https://dacon.io/competitions/official/235789/overview/description)의 5위 솔루션 코드를 정리하여 공개합니다.

## 1. 개요

WIP

## 2. 접근 방법 및 모델 설명

WIP

## 3. 설치 및 사용법
본 솔루션 코드 및 모델은 PyPI에 배포되어 있습니다. 다음과 같이 설치할 수 있습니다.
```bash
$ pip install sac2021
```
